# APARATPY

aparatpy is a video downloader library for [aparat.com](https://aparat.com)

#

## Install Aparatpy

```
pip install aparatpy
```

#

## Use Aparatpy

```python
from aparatpy import Main

video = Main('video-url', 'video-quality')
video.download()
```

#

## Links

Download Source Code: [Click Here](https://github.com/dori-dev/aparatpy/archive/refs/heads/main.zip)

My Github Acount: [Click Here](https://github.com/dori-dev/)
